package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````("8```````!``````````%BQ````
M`````````$``.``+`$``'``;``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"````````J`(````````<`````````!P``````````0`````````!````
M!````````````````````````````````````-@:````````V!H`````````
M$`````````$````%`````"``````````(``````````@````````S3L`````
M``#-.P`````````0`````````0````0`````8`````````!@`````````&``
M```````H1@```````"A&`````````!`````````!````!@```&"K````````
M8+L```````!@NP```````,`$````````2!4`````````$`````````(````&
M````B*L```````"(NP```````(B[````````0`(```````!``@````````@`
M````````!`````0```#$`@```````,0"````````Q`(```````!$````````
M`$0`````````!`````````!0Y71D!````%B?````````6)\```````!8GP``
M`````.P`````````[``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``!@JP```````&"[````````8+L```````"@!````````*`$`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!`````!````
M1TY5```````#`````@`````````$````%`````,```!'3E4`LRD8.H_4LPV@
M9DC%7[TTMJ%WVF<1````0P````0````(````(!P0``5`!(8H`D``D(8`@((I
M`"!)(`0)N*(93;H$!@H`````0P```$<```!+````3````%,```!4````5@``
M`%H```!;`````````%T```!@````8@```&,``````````````&[%WQ_JT^\.
MSMY'+6M_FGPNQ9NV(/_D#KB-\0[59-1\V7%8'.)'Q@&L2^/`\MO3';KCDGS"
MY3\L^J%L8+,!BV]K"4/69J_,9L6YG$!"1=7LQ(D%D(@'<-,Y\HL<#13BGMK-
MXYXS8MOM##J7"U:DFY:GW:-K?JF<F]%ESFWAIP(*"HH05Z/@^TD`````````
M````````````````````````````$0$``!(`````````````````````````
M_`$``!(`````````````````````````<@(``!(`````````````````````
M````4`(``!(`````````````````````````$0```"``````````````````
M````````>0(``!(`````````````````````````!0,``!(`````````````
M````````````M````!(`````````````````````````C@(``!(`````````
M````````````````@P$``!(`````````````````````````[0(``!(`````
M````````````````````Y0(``!(`````````````````````````A````!(`
M````````````````````````O`,``!(`````````````````````````#`$`
M`!(`````````````````````````L0(``!(`````````````````````````
MHP(``!(`````````````````````````80(``!(`````````````````````
M````_@(``!(`````````````````````````&P,``!(`````````````````
M````````9P$``!(`````````````````````````-0$``!(`````````````
M````````````P@```!(`````````````````````````L0$``!(`````````
M````````````````*0(``!(`````````````````````````6`(``!(`````
M````````````````````.0(``!(`````````````````````````G@$``!(`
M````````````````````````AP(``!(`````````````````````````]P$`
M`!(`````````````````````````7P,``!(`````````````````````````
M6`,``!(`````````````````````````0P$``!(`````````````````````
M````#@,``!(`````````````````````````+0```"``````````````````
M````````Q0(``!(`````````````````````````9````!(`````````````
M````````````%0(``!(`````````````````````````J@$``!(`````````
M````````````````DP```!(`````````````````````````GP```!(`````
M````````````````````7`$``!(`````````````````````````(@$``!(`
M````````````````````````5@```!(`````````````````````````%@$`
M`!(`````````````````````````S`(``!(`````````````````````````
MDP$``!(`````````````````````````\````!(`````````````````````
M````?P(``!(`````````````````````````\`$``!(`````````````````
M````````20,``!(`````````````````````````(@,``!(`````````````
M````````````=0$``!(`````````````````````````<P```!(`````````
M````````````````40,``!(`````````````````````````G`(``!(`````
M````````````````````U````!(`````````````````````````4P$``!(`
M````````````````````````V@(``!(`````````````````````````2P(`
M`!(`````````````````````````#0(``!(`````````````````````````
MMP(``!(`````````````````````````/````"``````````````````````
M````E0(``!(`````````````````````````J@(``!(`````````````````
M````````.P,``!(`````````````````````````Q0,``!(`#@#`6@``````
M`'<`````````DP,``!(`#P#$6P``````````````````\0,``!(`#@"P2P``
M`````"`+````````;`,``!(`#@#P(P```````"D"````````F0,``!(`#@`0
M10````````4`````````<`0``!(`#@`@10````````("````````:@0``!(`
M"P``(```````````````````G00``!(`#@#05@```````.D#````````7`0`
M`!``&0`@P```````````````````V`,``!(`#@`P1P```````"D`````````
M"P0``!$`$```8`````````0`````````O`$``!$`%0!PNP```````!,`````
M````2@0``!``&0"HT```````````````````:`0``!(`#@#00P```````#``
M````````?00``!(`#@#02@```````-X`````````CP0``!(`#@`@2@``````
M`'0`````````_@,``!``&```P```````````````````Y0,``!(`#@!@1P``
M`````,T`````````<0,``!$`&0!(P`````````@`````````T0,``!``&``@
MP```````````````````<@,``"$`&0!(P`````````@`````````0`0``!$`
M&``8P`````````@`````````]P(``!$`&0!@P`````````@`````````B0,`
M`!(`#@#`6P````````(`````````,`0``!(`#@!06P```````&4`````````
M!`0``!(`#@`@)@```````"L```````````0``"``&```P```````````````
M`````0$``!$`&0`@P`````````0`````````<P,``"$`&0!(P`````````@`
M````````J@,``!(`#@"@2@```````"<`````````+`,``"(`````````````
M````````````&@0``!(`#@!01````````+H`````````XP```!$`&0!`P```
M``````$`````````3P0``!(`#@`P2````````.<!`````````&QI8G!E<FPN
M<V\N-2XR-@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T
M87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M
M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S
M:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U
M;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!0
M97)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!0
M97)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R
M=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`
M4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``
M;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!R
M96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P=&AR96%D7V=E='-P96-I
M9FEC`&-L;W-E`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T
M<FYC;7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`
M<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`'-T
M<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK
M`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R
M96%D;&EN:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7V-X85]F
M:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?
M7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`;&EB8W)Y<'0N<V\N,0!?7VQI
M8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O
M;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A=&$`<&%R7V)A<V5N86UE`'!A
M<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN
M7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M
M>5]P87)?<&P`7V5N9`!P87)?:6YI=%]E;G8`7U]B<W-?<W1A<G0`>'-?:6YI
M=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A
M;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR+C4`1TQ)0D-?,BXQ
M-`!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0````"``,``@`"
M`````@`"`````@````(``@````(````"``(`!``"``(````````````#``(`
M!0````(``P`"``(````&````!P````,``@`````````````````&```````"
M``,``@`"```````"``(```````(``@`#``8````"``(`!@`!``$``0`!``$`
M`0`!``$``0`!``$````!``$``0`!``$``0`"``$``@`!``(``0`!``$``0``
M``(``0`"``$````!`````0`!`.`!```0````(````'4::0D```,`LP0`````
M```!``4`+P(``!``````````E)&6!@``!P"_!```$````'09:0D```8`R@0`
M`!````!R&6D)```%`-8$```0````%&EI#0``!`#B!```$````'4::0D```(`
MLP0```````!@NP````````@``````````"<```````!HNP````````@`````
M````P"8````````(P`````````@`````````",`````````8P`````````@`
M````````(&,```````"XOP````````8````%``````````````#`OP``````
M``8````*``````````````#(OP````````8````?``````````````#0OP``
M``````8````C``````````````#8OP````````8````K``````````````#@
MOP````````8````V``````````````#HOP````````8````_````````````
M``#POP````````8```!A``````````````!PNP````````4```!.````````
M```````@P`````````4```!>``````````````!`P`````````4```!C````
M``````````!(P`````````4```!5``````````````!@P`````````4```!9
M``````````````#@O0````````<````!``````````````#HO0````````<`
M```"``````````````#PO0````````<````#``````````````#XO0``````
M``<````$````````````````O@````````<````&```````````````(O@``
M``````<````'```````````````0O@````````<````(```````````````8
MO@````````<````)```````````````@O@````````<````+````````````
M```HO@````````<````,```````````````PO@````````<````-````````
M```````XO@````````<````.``````````````!`O@````````<````/````
M``````````!(O@````````<````0``````````````!0O@````````<````1
M``````````````!8O@````````<````2``````````````!@O@````````<`
M```3``````````````!HO@````````<````4``````````````!PO@``````
M``<````5``````````````!XO@````````<````6``````````````"`O@``
M``````<````7``````````````"(O@````````<````8``````````````"0
MO@````````<````9``````````````"8O@````````<````:````````````
M``"@O@````````<````;``````````````"HO@````````<````<````````
M``````"PO@````````<````=``````````````"XO@````````<````>````
M``````````#`O@````````<````@``````````````#(O@````````<````A
M``````````````#0O@````````<````B``````````````#8O@````````<`
M```D``````````````#@O@````````<````E``````````````#HO@``````
M``<````F``````````````#PO@````````<````G``````````````#XO@``
M``````<````H````````````````OP````````<````I```````````````(
MOP````````<````J```````````````0OP````````<````L````````````
M```8OP````````<````M```````````````@OP````````<````N````````
M```````HOP````````<````O```````````````POP````````<````P````
M```````````XOP````````<````Q``````````````!`OP````````<````R
M``````````````!(OP````````<````S``````````````!0OP````````<`
M```T``````````````!8OP````````<````U``````````````!@OP``````
M``<````W``````````````!HOP````````<````X``````````````!POP``
M``````<````Y``````````````!XOP````````<````Z``````````````"`
MOP````````<````[``````````````"(OP````````<````\````````````
M``"0OP````````<````]``````````````"8OP````````<````^````````
M``````"@OP````````<```!```````````````"HOP````````<```!!````
M``````````"POP````````<```!"````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%Q9\``$B%P'0"_]!(@\0(PP```````````/\UJIT``/\EK)T`
M``\?0`#_):J=``!H`````.G@_____R6BG0``:`$```#IT/____\EFIT``&@"
M````Z<#_____)9*=``!H`P```.FP_____R6*G0``:`0```#IH/____\E@IT`
M`&@%````Z9#_____)7J=``!H!@```.F`_____R5RG0``:`<```#I</____\E
M:IT``&@(````Z6#_____)6*=``!H"0```.E0_____R5:G0``:`H```#I0/__
M__\E4IT``&@+````Z3#_____)4J=``!H#````.D@_____R5"G0``:`T```#I
M$/____\E.IT``&@.````Z0#_____)3*=``!H#P```.GP_O___R4JG0``:!``
M``#IX/[___\E(IT``&@1````Z=#^____)1J=``!H$@```.G`_O___R42G0``
M:!,```#IL/[___\E"IT``&@4````Z:#^____)0*=``!H%0```.F0_O___R7Z
MG```:!8```#I@/[___\E\IP``&@7````Z7#^____)>J<``!H&````.E@_O__
M_R7BG```:!D```#I4/[___\EVIP``&@:````Z4#^____)=*<``!H&P```.DP
M_O___R7*G```:!P```#I(/[___\EPIP``&@=````Z1#^____);J<``!H'@``
M`.D`_O___R6RG```:!\```#I\/W___\EJIP``&@@````Z>#]____):*<``!H
M(0```.G0_?___R6:G```:"(```#IP/W___\EDIP``&@C````Z;#]____)8J<
M``!H)````.F@_?___R6"G```:"4```#ID/W___\E>IP``&@F````Z8#]____
M)7*<``!H)P```.EP_?___R5JG```:"@```#I8/W___\E8IP``&@I````Z5#]
M____)5J<``!H*@```.E`_?___R52G```:"L```#I,/W___\E2IP``&@L````
MZ2#]____)4*<``!H+0```.D0_?___R4ZG```:"X```#I`/W___\E,IP``&@O
M````Z?#\____)2J<``!H,````.G@_/___R4BG```:#$```#IT/S___\E&IP`
M`&@R````Z<#\____)1*<``!H,P```.FP_/___R4*G```:#0```#IH/S___\E
M`IP``&@U````Z9#\____)?J;``!H-@```.F`_/___R7RFP``:#<```#I</S_
M__\EZIL``&@X````Z6#\____)>*;``!H.0```.E0_/___R7:FP``:#H```#I
M0/S___\E"IP``&:0``````````!54TB#[#B)?"0<2(U\)!Q(B70D$$B-="00
M2(E4)`A(C50D"&1(BP0E*````$B)1"0H,<#H"/[__TB+-:F;``!(BSVJFP``
M2(GRZ`(W``"`/?N;````=2_H-/W__TB)!4VL``!(A<`/A*X!``!(B<?H;/S_
M_XL]MIL``.C1_?__QH#1"````(L]I)L``.B__?__BSV9FP``@(BJ!````NBM
M_?__@(BJ!````8M$)!R->`5(N/________\?2&/_2#G'#X<^`0``2,'G`TB-
M'1(]``#H^?S__TR+3"00QP6ZJP``!````$B)!:NK``!)BQ%(B5@(2(T=[#P`
M`$B)6!A(B1!(BQ4?FP``2(E0$(M4)!R#^@%^*HU*_KX!````2(/!`F8/'T0`
M`$V+!/&-?@1(@\8!2&/_3(E$^/A(.?%UZ(U*!$4QP(/"`TB+/6"K``!(8\E(
MC36V'@``2,=$R/@`````2(G!Z&7]__^)PX7`=%%(BSTXJP``2(UL)"3HWOO_
M_S'`2(GN2(T])CL``.BM%P``2(7`=#I(BST1JP``Z%S[___H]_S__XG82(M<
M)"AD2#,<)2@```!U:4B#Q#A;7<-(BSWGJ@``Z*+]__^)P^N?2(L]SZH``$B%
M_W0'Z.TT``#KLTB-/7TZ``!(B>[H3!<``$B)QTB)!:JJ``!(A<!TE>O92(TU
M=)4``$B-/5,Z```QP.AF_/__OP$```#H;/W__^@'^___#Q^``````#'M28G1
M7DB)XDB#Y/!05$R-!8HU``!(C0T3-0``2(T]K/W___\5?ID``/0/'T0``$B-
M/<F9``!(C07"F0``2#GX=!5(BP5.F0``2(7`=`G_X`\?@`````###Q^`````
M`$B-/9F9``!(C362F0``2"G^2,'^`TB)\$C!Z#](`<9(T?YT%$B+!3V9``!(
MA<!T"/_@9@\?1```PP\?@`````"`/:&9````=2]52(,]'ID```!(B>5T#$B+
M/2J9``#H_?S__^AH____Q@5YF0```5W##Q^``````,,/'X``````Z7O___]F
M+@\?A```````D$%73(U'.$R-5WA!5D%505154TB![)@"``!D2(L$)2@```!(
MB80DB`(``#'`2(GB28G19@\?1```08L`28LP28/`"$F#P1`/R(G`2(GQ28E!
M\$B)\$C!Z2!(P>@H2,'N."4`_P``2`GP2(G.2,'A"$C!YAB!X0``_P")]D@)
M\$@)R$F)0?A-.<)UKDB-L@`"```/'X``````2(M":$@S0D!(@\((2#-""$@S
M0OA(C0P`2,'H'T@)R(/@_TB)0GA(.?)UU4R+%TB+7Q!(BW<@2(MO&$R)T$R)
MTDR+3PA(P>H;2,'@!4@)T`,$)(V4,)EY@EI(B=A(BW0D"$@QZ$PAR$B-M#69
M>8):2#'H1(TL`DR)RDR)R$C!Z`)(P>(>38GH2`G"2(G82<'H&XG12#'(3"'0
M2#'82`'P3(GN2,'F!4P)QD2-)`9,B=9,B=!(P>8>2,'H`DV)XT@)\$B+="00
M2<'K&T@QPD&)P$PAZDB-M#.9>8):2#'*2`'R3(GF2,'F!4P)WD2-'!9,B>Y)
MP>T"2(M4)!A(P>8>3`GN2(V4$9EY@EI,B=E(,?!!B?9,(>!,,<!(P>D;2`'0
M3(G:2,'B!4@)RDR)X4G![`)(P>$>1(TL`DB)\$B+5"0@3`GA3(GN2#'(28V4
M$)EY@EI(P>X;08G,3"'83#'P2`'03(GJ2,'B!4@)\D2-!`),B=I)P>L"2(M$
M)"A(P>(>3(G&3`G:28V$!IEY@EI(P>X;2#'108G33"'I3#'A2`'!3(G`2,'@
M!4@)\$2--`A,B>A)P>T"2(M,)#!(P>`>3(GV3`GH28V,#)EY@EI(,<)!B<5,
M(<),,=I(`<I,B?%(P>$%2,'N&T@)\4R)QDG!Z`)(P>8>1(TD$4B+5"0X3`G&
M3(GA2#'P28V4$YEY@EI(P>D;08GP3"'P3#'H2`'03(GB2,'B!4@)RDR)\4G!
M[@)(P>$>1(T<`DB)\$B+5"1`3`GQ3(G>2#'(28V4%9EY@EI(P>X;08G.3"'@
M3#'`2`'03(G:2,'B!4@)\D2-+`),B>))P>P"2(M$)$A(P>(>3(GN3`GB28V$
M`)EY@EI(P>X;2#'108G43"'93#'Q2`'!3(GH2,'@!4@)\$2-!`A,B=A)P>L"
M2(M,)%!(P>`>3(G&3`G828V,#IEY@EI(P>X;2#'"08G#3"'J3#'B2`'*3(G!
M2,'A!4@)\4R)[DG![0)(P>8>1(TT$4B+5"183`GN3(GQ2#'P28V4%)EY@EI(
MP>D;08GU3"'`3#'82`'03(GR2,'B!4@)RDR)P4G!Z`)(P>$>1(TD`DB)\$B+
M5"1@3`G!3(GF2#'(28V4$YEY@EI(P>X;08G(3"'P3#'H2`'03(GB2,'B!4@)
M\D2-'`),B?)(BT0D:$C!XAY)P>X"3(G>3`GR28V$!9EY@EI(P>X;2#'108G6
M3"'A3#'!2`'!3(G82,'@!4@)\$2-+`A,B>!)P>P"2(M,)'!(P>`>3(GN3`G@
M28V,")EY@EI(P>X;2#'"08G$3"':3#'R2`'*3(GI2,'A!4@)\4R)WDG!ZP)(
MP>8>1(T$$4B+5"1X3`G>3(G!2#'P28V4%IEY@EI(P>D;08GS3"'H3#'@2`'0
M3(G"2,'B!4@)RDR)Z4G![0)(P>$>1(TT`DB)\$B+E"2`````3`GI3(GV2#'(
M28V4%)EY@EI(P>X;08G-3"'`3#'82`'03(GR2,'B!4@)\D2-)`),B<))P>@"
M2(N$)(@```!(P>(>3(GF3`G"28V$`YEY@EI(P>X;2#'108G03"'Q3#'I2`'!
M3(G@2,'@!4@)\$B+M"20````1(T<"$R)\$G![@)(P>`>28VT-9EY@EI-B=U,
M"?!)P>T;2#'"B<%,(>),,<)(`?),B=Y(P>8%3`GNB?9(`?),B>9)P>P"2,'F
M'D&)U4P)YDR+I"28````2#'P3"'83XV$()EY@EI-B>Q(,<A)P>P;3`'`38GH
M2<'@!4T)X$6)P$P!P$V)V$G!ZP))P>`>08G$30G828GSB?9(`[0DJ````$TQ
MPT0QVDR+G"2@````2HV,&:'KV6Y-B>-(`=%,B>))P>L;2,'B!4P)VHG22`'1
M3(GJ2<'M`DC!XAY!B<M,">I-B<5%B<!,`X0DL````$DQU40QZ$V)W4B-M`:A
MZ]EN3(G82<'M&TC!X`5,">B)P$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=))
M,?1$,>%-B>Q(`Y0DN````$V-A`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)
MV4G!ZP)(P>$>18G$3`G928GSB?9(`[0DP````$DQRT0QV$V)XTB-E`*AZ]EN
M3(G@2<'K&TC!X`5,"=B)P$@!PDR)Z$G![0)(P>`>08G33`GH28G-B<E(`XPD
MR````$DQQ44QZ$V)W4Z-A`:AZ]EN3(G>2<'M&TC!Y@5,">Z)]DP!QDV)X$G!
M[`))P>`>08GU30G@28G$B<!-,<1$,>)-B>Q(C8P1H>O9;DR)ZDC!X@5)P>P;
M2`.$)-````!,">*)TD@!T4R)VDG!ZP)(P>(>08G,3`G:38G#18G`3`.$)-@`
M``!),=-$,=Y-B>-(C;0PH>O9;DR)X$G!ZQM(P>`%3`G8B<!(`?!,B>Y)P>T"
M2,'F'D&)PTP)[DF)U8G22`.4).````!),?5$,>E-B=U-C80(H>O9;DR)V4G!
M[1M(P>$%3`GIB<E)`<A,B>%)P>P"2,'A'D6)Q4P)X4F)](GV23',1#'@38GL
M2(V4`J'KV6Y,B>A)P>P;2,'@!4P)X(G`2`'"3(G82<'K`D@#M"3H````2,'@
M'D&)U$P)V$F)RXG)2`.,)/````!),<-%,=A-B>-.C80&H>O9;DR)YDG!ZQM(
MP>8%3`G>B?9,`<9-B>A)P>T"2<'@'D&)\TT)Z$F)Q8G`2`.$)/@```!-,<5$
M,>I-B=U(C8P1H>O9;DR)VDG![1M(P>(%3`GJB=)(`=%,B>))P>P"2,'B'D&)
MS4P)XDV)Q$6)P$DQU$0QYDV)[$B-M#"AZ]EN3(GH2<'L&TC!X`5,">")P$@!
M\$R)WDC!YAY)P>L"08G$3`.$)``!``!,"=Y)B=.)TD@#E"0(`0``23'S1#'9
M38GC38V$"*'KV6Y,B>%)P>L;2,'A!4P)V8G)20'(3(GI2<'M`DC!X1Y%B<-,
M">E)B?6)]D@#M"00`0``23'-1#'H38G=2(V4`J'KV6Y,B=A)P>T;2,'@!4P)
MZ(G`2`'"3(G@2<'L`DC!X!Y!B=5,">!)B<R)R4DQQ$4QX$V)[$Z-A`:AZ]EN
M3(GN2<'L&TC!Y@5,">:)]DP!QDV)V$G!ZP))P>`>08GT30G828G#2`.,)!@!
M``")P$TQPT@#A"0@`0``1#':38GC2(V,$:'KV6Y,B>))P>L;2,'B!4P)VHG2
M2`'13(GJ2<'M`DC!XAY!B<M,">I-B<5%B<!,`X0D*`$``$DQU40Q[DV)W4B-
MM#"AZ]EN3(G82<'M&TC!X`5,">B)P$@!\$R)YDG![`)(P>8>08G%3`GF28G4
MB=)(`Y0D,`$``$DQ]$0QX4V)[$V-A`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!
MR$R)V4G!ZP)(P>$>18G$3`G928GSB?9),<M$,=A-B>-(`[0D.`$``$B-E`*A
MZ]EN3(G@2<'K&TC!X`5,"=A$C1P03(GH2<'M`DC!X!Y,">A)B<V)R4DQQ8G"
M13'H38G=3HV$!J'KV6Y,B=Y)P>T;2,'F!4P)[DR+K"1``0``1HTT!DV)X$G!
M[`))P>`>30G@3`G`1(G&28G$2(G02"'P32'<20G$N-R\&X])`<5,`>E-B?5)
M`<Q,B?%)P>T;2,'A!4P)Z4F)]4$!S$R)V4G!ZP)(P>$>3`G908G+20G(32'P
M32'=30GH3(NL)$@!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),
MB?))P>X"2,'B'DP)\DV)WD&)T$@)T4TAQDPAX4P)\4R+M"10`0``20'&3`'V
M38GN2`'Q3(GN2<'N&TC!Y@5,"?9$C30.3(GF2<'L`DC!YAY,">9-B<2)\4@)
M\DDAS$PAZDP)XDR+I"18`0``20'$30'C38GT3`':38GS2<'C!4G![!M-">-%
MC20338GK2<'M`DG!XQY-">M)B<U$B=I,"=Y)(=5,(?9,">Y,BZPD8`$``$D!
MQ4T!Z$V)Y4P!QDV)X$G![1M)P>`%30GH18TL,$V)\$G![@))P>`>30GP28G6
M1(G&30G#22'V32'C30GS3(NT)&@!``!)`<9,`?%-B>Y)`<M,B>E)P>X;2,'A
M!4P)\4:--!E,B>%)P>P"2,'A'DP)X4F)]$&)RTD)R$TAZ$TAW$T)X$R+I"1P
M`0``20'$3`'B38GT20'03(GR2<'L&TC!X@5,">)&C20"3(GJ2<'M`DC!XAY,
M">I-B=U!B=!("=%-(<5,(?%,">E,BZPD>`$``$D!Q4P![DV)Y4@!\4R)YDG!
M[1M(P>8%3`GN1(TL#DR)]DG![@)(P>8>3`GV38G&B?%("?))(<Y,(>),"?),
MB[0D@`$``$D!QDT!\TV)[DP!VDV)ZTG!XP5)P>X;30GS18TT$TV)XTG![`))
MP>,>30GC28G,1(G:3`G>22'43"'N3`GF3(ND)(@!``!)`<1-`>!-B?1,`<9-
MB?!)P>P;2<'@!4T)X$6-)#!-B>A)P>T"2<'@'DT)Z$F)U42)QDT)PTDA]4TA
M\TT)ZTR+K"20`0``20'%3`'I38GE20'+3(GA2<'M&TC!X05,">E&C2P93(GQ
M2<'N`DC!X1Y,"?%)B?9)"<A!B<M-(=Y-(>!-"?!,B[0DF`$``$D!QDP!\DV)
M[DD!T$R)ZDG![AM(P>(%3`GR1HTT`DR)XDG![`)(P>(>3`GB38G<08G02`G1
M32'$3"'I3`GA3(ND)*`!``!)`<1,`>9-B?1(`?%,B?9)P>P;2,'F!4P)YD2-
M)`Y,B>Y)P>T"2,'F'DP)[DV)Q8GQ2`GR22'-3"'R3`GJ3(NL)*@!``!)`<5-
M`>M-B>5,`=I-B>-)P>T;2<'C!4T)ZT6-+!--B?-)P>X"2<'C'DT)\TF)SD2)
MVDP)WDDAUDPAYDP)]DR+M"2P`0``20'&30'P38GN3`'&38GH2<'N&TG!X`5-
M"?!%C30P38G@2<'L`DG!X!Y-">!)B=1$B<9-"<-)(?1-(>M-">-,BZ0DN`$`
M`$D!Q$P!X4V)]$D!RTR)\4G![!M(P>$%3`GA1HTD&4R)Z4G![0)(P>$>3`GI
M28GU08G+20G(32'P32'=30GH3(NL),`!``!)`<5,`>I-B>5)`=!,B>))P>T;
M2,'B!4P)ZD:-+`),B?))P>X"38G82,'B'DP)\D&)UD@)T4TA\$PAX4P)P4R+
MA"3(`0``20'`3`'&38GH2`'Q3(GN2<'H&TC!Y@5,"<9$C00.3(GF2<'L`DR)
M\4C!YAY,">9!B?1("?),(>%,(>I("<I(BXPDT`$``$@!P4D!RTR)P4@#A"38
M`0``3`':38G#2,'A!4P!\$G!ZQM,"=F)R4@!RDR)Z4G![0)(P>$>08G33`GI
M38GE08G/2`G.32']3"'&3`GN38G=2`'P3(G>2<'M&TC!Y@5,">Z)]D@!\$R)
MQDG!Z`)(P>8>08G%20GPOM;!8LI,,<$QRDB+C"3@`0``2`'Q20',3(GI3`'B
M38GL2,'A!4G![!M,">&)R4@!RDR)V4C!X1Y)P>L"08G420G+3(G!38GF18G`
M3#'92<'N&S'(2(N,).@!``!(`?%)`<]*C0PX3(G@2,'@!4P)\(G`3(TT`4R)
MZ$G![0),B=E(P>`>18GW18G;20G%2(N$)/`!``!,,>E(`?`QRDR)^4P!P$C!
MZ1M(`<),B?A(P>`%2`G(2(N,)/@!``")P$@!PDR)X$@!\4G![`)(P>`>3`'9
M38GK08G03`G@38G$18GM23'#2<'L&T4QWDZ-'#%,B<%(P>$%3`GAB<E)`<M,
MB?E)P>\"2,'A'D6)W$D)STB+C"0``@``2`'Q3`'I28G%B<!-,?U$,>I,C2P1
M3(GB3(GA2,'I&TC!X@5("<I,B<%)P>@"B=)(P>$>20'52(N4)`@"``!,"<%-
MB?A),<A%B>Y%B?](`?)%,<-(`=!,B?).C0083(GP2,'J&TC!X`5("=!(B<J)
MR8G`20'`3(G@2<'L`DC!X!Y%B<-)"<1(BX0D$`(``$PQXD@!\$$QU4R)VDP!
M^$D!Q4R)V$C!X`5(P>H;2`G03(GR2<'N`HG`2,'B'DD!Q4B+A"08`@``3`GR
M18GO2`'P2`'(3(GA18GD2#'103'(3(GY20'`3(GX2,'I&TC!X`5("<B)P$D!
MP$R)V$G!ZP)(P>`>18G&20G#2(N$)"`"``!,B?%(P>D;2`'P3`'@28G4B=)-
M,=Q%,>5.C20H3(GP2,'@!4@)R$B+C"0H`@``B<!)`<1,B?A(`?%)P>\"2,'@
M'D@!RDR)V46)Y4P)^$6)VT@QP4$QR$R)Z4D!T$R)ZDC!Z1M(P>(%2`G*B=))
M`=!,B?))P>X"2,'B'D6)QTD)UDB+E"0P`@``3(GY2,'I&T@!\DP!VDF)PXG`
M33'S13'<3HT<(DR)^DC!X@5("<I,B>E)P>T"B=)(P>$>20'32(N4)#@"``!,
M">E%B=Q(`?)(`=!,B?)%B?9(,<I!,=!,B>))`<!,B>!(P>H;2,'@!4@)T$B)
MRHG)B<!)`<!,B?A)P>\"2,'@'D6)Q4D)QTB+A"1``@``2`'P3#'Z3`'P03'3
M3(GJ20'#3(GH2,'J&TC!X`5("=!,B>))P>P"B<!(P>(>20'#2(N$)$@"``!,
M">)%B=Y)B=1(`?!(`<A,B?E%B?](,=&)TD$QR$J-#`!,B?!-B?!)P>@;2,'@
M!4P)P(G`2`'!3(GH2<'M`DC!X!Y!B<A)"<5(BX0D4`(``$TQ[$@!\$4QXTV)
MQ$P!^$G![!M)`<-,B<!(P>`%3`G@B<!)`<-,B?!(P>`>2<'N`D6)W$P)\$R+
MM"18`@``20'V20'63(GJ18GM2#'",=%)C10.3(GA38GF2<'N&TC!X05,"?&)
MR4@!RDR)P4G!Z`)(P>$>08G620G(2(N,)&`"``!(`?%,`>E)B<6)P$TQQ44Q
MZTV)]4D!RTR)\4G![1M(P>$%3`GIB<E)`<M,B>%)P>P"2,'A'D6)W4D)S$B+
MC"1H`@``2`'Q2`'(3(G!18G`3#'A,<I(C0P03(GH3(GJ2,'J&TC!X`5("=!,
MB?))P>X"2,'B'HG`20G62(N4)'`"``!(`<&)R$@!\DP!PDV)X$TQ\$4QPTF)
MP$P!VDF)PTG!X`5)P>L;30G828G#2,'H`DG!XQY!`=!,B>I)P>T"20G#2(N$
M)'@"``!(P>(>20G51(GB00';2`'P1`'M3(E?$$@!PDR)\$B);QA,,>@QP4B-
M!`I,B<),B<%%`<A(P>(%2,'I&TR)1PA("<H!T$$!PD0#=R!,B1=,B7<@2(N$
M)(@"``!D2#,$)2@```!U$DB!Q)@"``!;74%<05U!7D%?P^CZX___9BX/'X0`
M`````$%7059!54%455-(@^P(2(7_#X2Q````3(L]^H(``$V%_P^$H0````^V
M!X3`=`0\/75>13'D28L?2(7;=#E)B?5)B?Y-8^1,B?T/'X``````3(GB3(GV
M2(G?Z-+B__^%P'4'0H`\(SUT1TB#Q0A(BUT`2(7;==I(@\0(2(G86UU!7$%=
M05Y!7\,/'X0``````$F)_$F#Q`%!#[8$)(3`=`0\/77O02G\ZXP/'X``````
M3"G]2HU<(P%(P?T#08EM`.NT9@\?1```,=OKJ@\?0`!52(G]4TB#[!AD2(L$
M)2@```!(B40D"#'`2(U<)`1FD#'`2(G>2(GOZ`/___](A<!T-DAC5"0$2(L%
M"H(``$B-!-!(BU`(2(D02(72=-)FD$B#P`A(BU`(2(D02(72=?#KOF8/'T0`
M`$B+1"0(9$@S!"4H````=0=(@\086UW#Z)SB__]F9BX/'X0``````)!!5T%6
M055!5%5(B?532(G[2(/L*&1(BP0E*````$B)1"08,<`QP(`^/0^4P$@!Q4B)
M[^A)XO__2(UT)!1(B=])B<0QP.A7_O__2(7`#X0.`0``2(G'28G%Z"/B__],
M.>`/@]H```!,8W0D%$G!Y@,/M@.$P`^$K@$``#P]#X2F`0``2(G8#Q\`2(/`
M`0^V$(32=`6`^CUU\$@IV$B82HU\(`),`S4/@0``Z!+C__])B09(A<`/A((!
M``!(BP7W@```2&-4)!1(C4L!2(L4T`^V`X@"/#UT'X3`=0GK&0\?`#P]=!)(
M@\$!#[9!_TB#P@&(`H3`=>K&`CTQP`\?1```#[9,!0"(3`(!2(/``83)=>\Q
MP$B+7"089$@S'"4H````#X4?`0``2(/$*%M=05Q!74%>05_#9BX/'X0`````
M`#'`9@\?1```#[94!0!!B%0%`$B#P`&$TG7NZ[4/'T``3(L]48```$F#/P`/
MA+X```!,B?@QTNL+#Q^$``````!$B>I(@\`(1(UJ`4B#.`!U[XUR`TAC]DC!
MY@.+!4^0``"%P'5;QP5!D````0```$B)]^@)XO__2(7`#X1\````36/%3(G^
M2(G'3HTTQ0````!,B40D"$R)\NB2XO__3(M$)`A(B07.?P``2(G!2L=$P0@`
M````1(EL)!3I;_[__TR)_^A(XO__2(G!2(D%IG\``$B%P'0E36/%3HTTQ0``
M``#KR0\?0``QP.EN_O__OA````!%,>WI7____[C_____Z<W^___H1>#__P\?
M1```05=!5D%505154TB![+@```!D2(L$)2@```!(B80DJ````#'`2(7_=`B`
M/P!(B?MU+TB+A"2H````9$@S!"4H````#X4O`0``2('$N````%M=05Q!74%>
M05_#9@\?1```Z'O?__](B<5(A<!TQ$B-1"003(TEK!X``$B)1"0(3(TUGQX`
M`$B)[^BCX?__2(7`#X3"````3(UX$[D"````3(GG3(G^\Z8/E\`<`(3`=-6Y
M`P```$R)_DR)]_.F#Y?`'`"$P'2_2(G?Z&+?__],B?])B<7H5]___T&-?`4"
M2&/_Z(K@__]-B?E)B=B^`0```$F)Q4B)QS'`2,?"_____TB-#2`>``#HY.'_
M_TB+5"0(OP$```!,B>[HLM[__TR)[X/X_W00BT0D*"4`\```/0!```!T.N@U
MWO__3(GOZ`W>__](B>_HY>#__TB%P`^%0O___P\?0`!(B>_H8-___TB)W^BX
MWO__Z<3^__\/'P#HB_[__^O$Z,3>__\/'T``4TB)_DB)^[\!````2('LH```
M`&1(BP0E*````$B)A"28````,<!(B>+HXN#__X7`=3:+5"08@>(`\```@?H`
M0```=`B!^@"@``!U'KX"````2(G?Z'?@__^%P`^4P`^VP.L'#Q]$```QP$B+
MC"28````9$@S#"4H````=0E(@<2@````6\/H-=[__P\?1```05:Z_P\``$F)
M]D%5051)B?Q(C3T%'0``55-(@>P0$```9$B+!"4H````2(F$)`@0```QP$B)
MXTB)WNA1W?__A<!^=8U0_T2++>-\``!(8^J`/"P`=5J%TG1E2(GJOB\```!(
MB=_H=M[__TB%P'101(GOZ-G>__](B>E(B=I,B>9(B<?HV-___TB+A"0($```
M9$@S!"4H````=3Q(@<00$```6UU!7$%=05[##Q]$``!(8^CKI0\?`$2++7%\
M``!$B>_HB=[__TR)\DR)YDB)Q^B;W?__Z['H5-W__P\?0`!(@^P(BSU&?```
MZ&'>__](BQ7:>P``2(/$"$B-#1<>``!(C34D'```2(G'Z8#>__](@^P(BST6
M?```Z#'>__](B<?HN?___XL]`WP``.@>WO__3(T%B!T``$4QR4B-%9T2``!,
MB<%(C37[&P``2(G'2(/$".F'WO__#Q^``````%532('L*"```&1(BP0E*```
M`$B)A"08(```,<!(B>-(C:PD$!```.@DW/__2(T-RAL``+H!$```2(G?08G`
M3(T-@QL``+X!````,<#H+]___[H`$```2(GN2(G?Z,_;__\QR87`>"Z->`%(
MB<-(8__HB]W__TB)P4B%P'082&/;2(GN2(G'2(G:Z$+=___&!!@`2(G!2(N4
M)!@@``!D2#,4)2@```!(B<AU"DB!Q"@@``!;7</H%MS__V8/'T0``.D[____
M9F8N#Q^$``````!!5T%6055!5$F)]%5(B?U(C3TC&P``4TB![+@0``!D2(L$
M)2@```!(B80DJ!```#'`2(UT)`SHU??__[XO````2(GO2(G#Z-7;__](A<!T
M0$B)[DB-/>@:```QP.@/^?__2(GH2(N,)*@0``!D2#,,)2@````/A8(!``!(
M@<2X$```6UU!7$%=05Y!7\,/'P!(B>_H6-O__TB--;`:``!,B>=!B<7H=MW_
M_TF)QTB%P'2>08/%`4&`/P!,C70D$$R-I"2@````#X3)````#Q\`2(7;=!-,
MB?Y(B=_H\-O__X7`#X2*````3(G_Z`#;__^)PDB808!\!_\O=1</'T``@^H!
M2&/"08!\!_\O0<8$!P!T[40!ZH'Z_P\```^/+O___TB#[`A(C0T:&P``38GX
M,<!53(T-%QH``+H`$```3(GGO@$```#H9-W__TR)\DR)YK\!````Z#3:__]:
M687`=1"+1"0H)0#P```]`(```'1>2(TUUAD``#'_Z*#<__])B<=(A<`/A,3^
M__]!@#\`#X4Z____2(7;=!VY`@```$B)WDB-/3L9``#SI@^7P!P`A,!TO0\?
M`$R-/289``"Z`0```.E*____#Q^``````+X!````3(GGZ#/<__^%P'613(GF
M2(T]5QD``.B`]___3(GGZ)C<___I9_[__^C^V?__9F8N#Q^$```````/'P`/
MMA=(B?B$TG0>9@\?1```2(/'`8#Z+P^V%T@/1,>$TG7NPP\?1```PP\?@```
M``!(A?\/A*<```"`/P`/A)X```!32(G[Z)79__](C50#_T@YTW(4ZR=F#Q^$
M``````!(@^H!2#G3=!J`.B]T\NL%@#HO="A(@^H!2#G3<O)(.=-U&H`Z+W1H
M2(T]LA@``%OIZ]O__P\?`(`Z+W4)2(/J`4@YTW+R2"G:,<!(C4H"2('Y`!``
M`'<?2(/"`;D`$```2(G>2(T]A7@``.BPVO__2(T%>7@``%O##Q^``````$B-
M/>X7``#IE-O__P\?0`!(C3W>%P``6^F#V___#Q\`4TB-/3L8``!(@^Q`\P]O
M!9P9``#S#V\-I!D``&1(BP0E*````$B)1"0X,<`/MP6=&0``2(U<)`P/*40D
M$&:)1"0P,<`/*4PD(.B"]?__,<!(C3WU%P``Z'3U__\QP$B-/>\7``#H9O7_
M_S'`2(T]ZA<``.A8]?__,<!(C3WC%P``Z$KU__\QP$B-/>47``#H//7__S'`
M2(T]C!<``.@N]?__,<!(C3W5%P``Z"#U__\QP$B-/=$7``#H$O7__S'`2(T]
MS1<``.@$]?__,<!(C3U=%P``Z/;T__\QP$B)WDB-/;@7``#H%?3__TB%P'01
M2(G&2(T]D!<``#'`Z%_U__\QP$B)WDB-/:(7``#H[O/__TB%P'012(G&2(T]
MH!<``#'`Z#CU__\QP$B)WDB-/9@7``#HQ_/__TB%P'1"2(G&2(T]X18``#'`
MZ!'U__\QP$B--:`7``!(C3T%%P``Z/ST__](BT0D.&1(,P0E*````'5N2(/$
M0%O#9@\?1```,<!(B=Y(C3U0%P``Z&_S__](A<!T&DB)QDB-/>`6```QP.BY
M]/__ZZ8/'X``````2(UT)"&Y"@```$B-/2P7``#SI@^7P!P`A,!U@TB-="0K
M2(T]J!8``.B#]/__Z6W____H"=?__V8/'X0``````$B#[!AD2(L$)2@```!(
MB40D"#'`BP76=0``@_C_=!E(BWPD"&1(,SPE*````'5`2(/$&,,/'T``2(UT
M)`1(C3U,%@``,<#HQ?+__TB)PC'`2(72=!(/MA*`^C`/E<$QP(32#Y7`(<B)
M!8-U``#KL.B,UO__9F8N#Q^$``````"02(/L".B'UO__B<?H,-;__TB%P'0+
M2(L`2(/$",,/'P`QP$B#Q`C#9@\?A```````05152(G]2(T]318``%-(@^P0
M9$B+!"4H````2(E$)`@QP$B-="0$Z#3R__](B>Y(A<!T"(`X`$B)PW4L2(T]
M%Q8``#'`Z';S__](BT0D"&1(,P0E*````'5_2(/$$%M=05S##Q]$``!(B<?H
M@-C__TB%P'752(GOZ,/5__](B=])B<3HN-7__TF-?`0"Z.[6__](@^P(28GH
MO@$```!32,?"_____TB)QTF)Q$R-#>P4``!(C0W=%0``,<#H/]C__TR)YDB-
M/8\5```QP.CN\O__6%KI<?___^ARU?__9I!!5TF)_TB-/9T4``!!5D%50515
M4TB![)B!``!D2(L$)2@```!(B80DB($``#'`2(T%814``$R-9"0L2,=$)$``
M````2(E$)#!(C04&%```3(GF2(E$)#A(C07C%```2(E$)'!(C070%```2(E$
M)'A(C04E%0``2(F$)(````!(C072%```2(F$)(@```!(C04/%0``2(F$))``
M``!(C07G%```2(E$)%!(C07X%```2(E$)%@QP$C'A"28`````````$C'1"1@
M`````.BP\/__2(7`=`F`.``/A;($```QP.@+_O__2(G#2(7`#X0O!```2(G?
MZ&?4__](C7P``>B=U?__@#L`28G%=#=,B>U,C36;%```#Q\`1`^V`TB)[S'`
M3(GQ2,?"_____[X!````2(/#`4B#Q0+HX];__X`[`'762(U<)'!(C3WS$P``
MZQ!(@\,(2(L[2(7_#X28`0``3(GF,<#H%O#__TB)Q4B%P'3>@#@`=-E(B<?H
M,?7__X7`=,U(B>_H==;__TF)QDB%P`^$80$``&8/'X0``````$R)\8L12(/!
M!(V"__[^_O?2(=`E@("`@'3IB<+!ZA"I@(````]$PDB-40)(#T3*B<(`PDR)
MZDB#V0-,*?&+,DB#P@2-AO_^_O[WUB'P)8"`@(!TZ8G&P>X0J8"````/1,9(
MC7("2`]$UHG&0`#&2(/:`TPIZHV<$00$``!(8]M(B=_H>=3__T%538GPO@$`
M``!(B<5(C06#$P``3(T-?Q(``$C'PO____]02(T-9!,``$B)[S'`Z,75__^^
MP`$``$B)[^A8TO__05A!68/X_W42Z!K2__]$BPA!@_D1#X7F`@``3(VL)*``
M``!(B>Z_`0```$R)ZN@EU?__08G&A<`/A*H```!)BP](BST`<@``28GH,<!(
MC17L$P``O@$````QV^@HU?__2(N,)(B!``!D2#,,)2@```!(B=@/A3D(``!(
M@<28@0``6UU!7$%=05Y!7\,/'T``,>UF#Q]$``!(8\5(BUS$,$B%VW0[@#L`
M=#9(B=^#Q0'HD_/__X7`=-](B=_HU]3__TF)QDB%P`^%:_[__TACQ4B+7,0P
M2(7;=<MF#Q]$``!%,?;I4/[__XN$)+@````E`/```#T`0```#X4_____BX0D
MO````(D$).@*TO__.00D#X4G____BX0DN````"7_`0``/<`!```/A1#___](
MB=_H`M/__TR)YDB-/=T1``!(B<,QP.C.[?__2(7`#X05`@``2(G'Z#W4__])
MBS](B<;HHO7__TF)Q$B%P`^$]@$``$R)Y^A^T?__@_@#?D%(8]"Y!0```$B-
M/<T1``!)C704_/.F#Y?"@-H`A-)U(8/X!`^$L`4``(/H!$B808!\!/\O#X2?
M!0``#Q^``````#'`Z$'Z__^%P'45,?9,B>?H`]/__XD$)(7`#X60`0``2(TU
M*1$``$B-/:H0```QP.B#[O__3(TEG1$``$R-+580``#H@-#__T%428GHO@$`
M``!02,?"_____TB)WS'`3(T-,Q```$B-#4<1``#HAM/__UA:ZT5FD.CKS___
M@S@1=4OH0=#__T&#Q@%(@^P(38GI051)B>A(C0TD$0``2(G?059(Q\+_____
MO@$```!0,<#H0=/__TB#Q""^P`$``$B)W^C0S___@_C_=*M(B>_H@\___TB)
MWDB-/:(/```QP.C2[?__2(G?Z`KZ___IK?W__P\?1```2(T]8Q```#'MZPT/
M'T0``$ACQ4B+?,102(7_='-,B>8QP(/%`>@V[/__2(7`=.&`.`!TW$B)Q^BD
MTO__2(G#2(7`=,SIB/O__TF+#TB+/3UO``!)B>@QP$B-%>D0``"^`0```#';
MZ&72___I./W__TB)QTB)!"3HA/G__TB+!"1(B<?H6-+__TB)P^D8_?__OPT`
M``!(C1W3#P``Z-_0__])B<7I0OO__P\?@`````!-BR?I`O[__[H"````2,?&
M[O___T&)QXG'Z/+1__],C;0D@`$``+H&````1(G_3(GVZ"K0__^`O"2``0``
M`'4.@+PD@0$``$,/A'0$``"+/"0QTC'VZ+;1__^XB:O-[TC'A"2@`````2-%
M9TB)A"2H````2"V+SA)72(F$)+````!(!?($&"M(B80DP````$F-13A(QX0D
MN````'94,A!(QX0DR`````````!(QX0DT`````````#'A"08`0```````$B)
M1"009@\?A```````BSPDN@"```!,B?;H@,___TB)P4&)P(7`#XYB`0``2(N\
M),@```!(8\%(BY0DT````(TTQT@Y_DB)M"3(````2(/2`$C!Z!U(`=!(B80D
MT````$ACA"08`0``A<`/A!8!``!!N$````!(B4PD"$R)]D$IP$0YP40/3L%(
MBTPD$$UC^$B-/`%,B?KH0L___XN$)!@!``!(BTPD"$0!^(/X0(F$)!@!```/
MA5/___]!B<A,B>]%*?A-`?=$B40D".C]T___1(M$)`A!@_@_#XZ0`@``08U`
MP(E$)!S!Z`9!B<2)1"0(28/$`4G!Y`9-`?R0\T$/;P_S00]O5Q!,B>])@\=`
M\T$/;U_@\T$/;V?P#Q&,)-@````/$90DZ`````\1G"3X````#Q&D)`@!``#H
MC=/__TTYYW6XBT0D"$2+1"0<P>`&02G`2(M\)!!)8]"Y2````$R)YD2)1"0(
MZ%_.__]$BT0D"$2)A"08`0``Z8W^__\/'T0``$V)]^E(____BSPDZ+C-__](
MBX0DR````$2+I"3(````1(NT)-````!(P>@#00_,@^`_00_.C5`!2)C&A`38
M````@(/Z.`^.IP$``+A`````2&/**=!)C70-.(G"=`\QP(G!@\`!Q@0.`#G0
M<O-,B>_HT]+__V8/[\`/$80DV````$G'16@`````00\114A!#Q%%6$R)[T2)
MM"00`0``3(V\)#$!``!,C;0D>`$``$2)I"04`0``3(TMVPP``.B&TO__BX0D
MH````$0/MH0DHP````_(B80D,`$``(N$)*@````/R(F$)#0!``"+A"2P````
M#\B)A"0X`0``BX0DN`````_(B80D/`$``(N$),`````/R(F$)$`!``!(C80D
M4`$``$B)!"1)B<3I$0```&8/'X0``````$4/M@=)@\<!3(GG10^VP$R)Z;X!
M````2,?"_____S'`28/$`NBGSO__33GF==)(C05\#```QH0D>`$```!0_W0D
M"$B-#30,``!)B>A(B=\QP+X!````3(T-%`L``$C'PO_____H9\[__UE>Z37[
M__]-BW\(387_#X1;^O__3(G_Z(O+__](@_@##X9)^O__28UT!_RY!0```$B-
M/=@+``#SI@^7P!P`A,!-#T3GZ2;Z__]-B?SIW?W__[@X````,?\IT$ACTDF-
M5!4X@_@(<S"H!`^%X````(7`#X1[_O__Q@(`J`(/A'#^__\Q_V:)?`+^Z63^
M__]F#Q^$``````")P4C'`@````!(QT0*^`````!(C4H(2(/A^$@IR@'0@^#X
M@_@(#X(P_O__@^#X,=*)UH/""$B)/#$YPG+SZ1G^__^`O"2"`0``00^%?OO_
M_X"\)(,!``!##X5P^___@+PDA`$``$@/A6+[__^`O"2%`0``10^%5/O__T2+
M/"2Z`@```$C'QL;___]$B?_H_LS__[HI````3(GV1(G_Z#[+__](C04("P``
M4$%6Z9'^__\/'X``````QP(`````QT0"_`````#ID/W__^A0RO__05=!5D%5
M05154TB#[!B+/3QI``!D2(L$)2@```!(B40D"#'`3(UL)`3H0LO__XL]'&D`
M`$B)P^@TR___#[:3N````$R)[DB-/7<)``"(D+D````QP.@&YO__2(7`=`F`
M.#$/A`@#```QP.CQ\/__BSW;:```Z/;*__^Y"P```+H!````2(TU4`H``$B)
MQ^B=RO__2(7`#X3$````2(M`$(,]&7D```%$BS6B:```3(M@*`^.KP```#';
MZS8/'T``28MW$$B+#>UX``!(8]5(BSS1Z$G*__^+%>-X``"%P`^%$`(``(/#
M`CG3B>L/C0,"``!$B?>-:P'H<\K__S')2&/33(GF2(G'Z$/+__](A<`/A-(!
M``!,BSA$BS4P:```08M'#"4`!"``/0`$``!TD$2)]^@XRO__3(G^N0(````Q
MTDB)Q^A6R?__1(LU_V<``$B)QNEK____#Q^``````$2+->EG``!$B??H`<K_
M_[D#````N@$```!(C35@"0``2(G'Z*C)__](B<-(A<!T-4B+0!"+/;9G``!(
MBRCHSLG__TB-%3D)``!(B<=(B>[HW,C__TB+0Q!(BQCV0PY`#X7G`0``BSV%
M9P``Z*#)__^Y`P```+H!````2(TU!@D``$B)Q^A'R?__2(G#2(7`=#U,B>Y(
MC3V7!P``,<#H7N3__TB)Q4B%P`^$<@$``$B+0Q"+/3AG``!(BQCH4,G__TB)
MZDB)WDB)Q^ABR/__BST<9P``Z#?)__^Z`0```$B--:0(``!(B<?H0\G__XL]
M_68``$B)P^@5R?__2(G>2(T5F0@``$B)Q^@CR/__BSW=9@``Z/C(__],B>Y(
MC3T'!P``QH"Y`````#'`Z-#C__](B<-(B04N=P``2(7`#X2=````OL`!``!(
MB=_H\,;__XU0`8/Z`78)@_@1#X4+`0``2(M$)`AD2#,$)2@````/A?(```!(
M@\086UU!7$%=05Y!7\,/'T``BQ72=@``1(LU6V8``(U"_SG8#X5G_O__@_H!
M#XY>_O__NP$```!FD$2)]X/#`>A5R/__3(GF2(G'Z)K&__\Y'91V``!$BS4=
M9@``?]OI+?[__V8/'T0``$B+/7%V``#HE/'__TB)PTB)!7)V``!(A<`/A43_
M__](C3UZ"```,<#H,\C__P\?`(!X`0`/A/7\___IZ?S__Y!(BP4Q=@``BSW#
M90``2(LH2(M#$$B+&.C4Q___2(GN2(G?Z'GH___I@O[__XL]GF4``.BYQ___
M2(G>2(G'Z`[(___I_OW__^B$QO__B<%(BP7C=0``2(G:2(T]*0@``$B+,#'`
MZ+?'__\/'X``````54B)_5-(@^P(Z)+L__\/MA!(B<.$TG0:#Q^$``````!(
M@\`!@/HO#[802`]$V(32=>XQP.@G[___2(7M="2%P'0@@'T``'0:N00```!(
MC3U:!@``2(G>\Z8/E\`<`(3`=`=(@\0(6UW#2(/$"$B)[UM=Z:GE__]F#Q^$
M``````!(BPW!9```Z63&__\/'T``05=!5DF)UT%5051,C27^7P``54B-+?Y?
M``!308G]28GV3"GE2(/L"$C!_0/H?\3__TB%[70@,=L/'X0``````$R)^DR)
M]D2)[T'_%-Q(@\,!2#G==>I(@\0(6UU!7$%=05Y!7\-F9BX/'X0``````//#
M``!(@^P(2(/$",,`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?
M4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P
M,G@`)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E
M<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2
M.CI086-K97(Z.E9%4E-)3TX`,2XP-#<`+64`+2T`````````7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("```````````'!E<FQX<VDN8P``````
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@```````%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER
M96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``````````!E=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?
M<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@
M>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G
M+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E
M;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS
M;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I
M;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@
M)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<[
M"F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP
M+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/
M3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"![
M"E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T
M7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U
M8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO
M9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY
M("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F
M9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD
M;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE
M(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*
M9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S
M("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!
M4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I
M>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL
M87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E
M96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@
M7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&
M2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R
M97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE
M("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA
M;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]
M("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B
M+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*
M96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y
M.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C
M(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D
M8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D
M=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4[
M"FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T
M*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA
M<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D
M:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H
M("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F
M:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA
M;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H
M+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE
M.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@
M0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ
M1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I
M<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I
M;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC
M/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N
M86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\[
M"GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@
M=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L
M92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?
M4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P
M<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@
M)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H
M;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]4
M14U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@
M0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`
M05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG
M+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO
M9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A
M9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II
M<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@
M>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O
M;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A
M;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L
M("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D
M<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P
M,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z
M.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O
M<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D
M;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS
M;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT
M.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA
M9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T
M(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[
M)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D
M,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R
M*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL
M97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@
M=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI
M8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE
M<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC
M*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2![
M"B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;
M7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T
M.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII
M9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M
M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D
M,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD
M(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A
M;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L
M"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D
M9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I
M*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)
M3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2([
M"F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S
M*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD[
M"B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F
M:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E
M;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP
M.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF
M("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY
M72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S
M:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*
M?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@
M>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H
M*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H
M("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP
M<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^
M=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP
M;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*
M>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA
M;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@
M;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@
M(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?
M1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]4
M14U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H
M("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O
M<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT
M('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N
M9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D
M,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM0
M05)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S
M*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M
M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H
M,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU
M;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N
M(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED
M:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*
M)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS
M=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL
M93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U
M:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL
M97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B
M(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,
M;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I
M<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U
M:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD
M;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6([
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@
M?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D
M<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA
M;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!
M3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P
M96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R
M.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#
M2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T
M,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS
M."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE
M*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X
M(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T
M>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E
M('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7([
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q
M(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D
M;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92([
M"G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L
M;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE
M(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R
M:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T
M96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D
M9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L
M;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@
M)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O
M9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?
M97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E
M>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA
M;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]
M("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD
M969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P
M=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1
M)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!
M4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A
M97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@
M<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.
M5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<
M4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L
M;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B
M0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S
M:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]
M+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L
M:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E
M(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD
M7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@
M0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F
M:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D
M<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`
M(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%
M4E)/4CL*,3L*7U]%3D1?7PH```````$;`SOL````'````,B`__\X`0``B(3_
M_V`!``"8A/__+`8``,B&__\(`0``N(?__W@!``#8G?__R`$``*B>__\4`@``
M.)___T`"``"(H?__C`(```BC___8`@``F*/___P"``!XI/__0`,``*BD__]8
M`P``^*3__W`#``"XI?__G`,``,BE__^P`P``V*?__Q`$```(J/__)`0``-BH
M__]4!```R*K__W@$``!(J___E`0``'BK__^T!```6*S___0$``!XM___K`4`
M`&B[___X!0``Z+O__U@&``#XN___<`8``&B\__^X!@```````!0`````````
M`7I2``%X$`$;#`<(D`$'$!0````<````N(7__RL``````````````!0`````
M`````7I2``%X$`$;#`<(D`$``"0````<````B'___\`#````#A!&#AA*#PMW
M"(``/QH[*C,D(@`````4````1````""#__\(``````````````!,````7```
M`#B&__\6%@```$(.$(\"2@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.T`4#
M[14*#CA!#C!!#BA"#B!"#AA"#A!"#@A!"P```$@```"L````")S__\P`````
M0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y``FP*#CA$#C!!#BA"
M#B!"#AA"#A!"#@A)"P`H````^````(R<__^$`````$$.$(8"1`X8@P-$#C`"
M<PH.&$$.$$$."$$+`$@````D`0``\)S__TL"````0@X0CP)"#AB.`T(.((T$
M0@XHC`5!#C"&!D0..(,'1PY@`Q<!"@XX00XP00XH0@X@0@X80@X00@X(2PM(
M````<`$``/2>__]\`0```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#
M!T<.\`%^"@XX00XP00XH0@X@0@X80@X00@X(1PL`(````+P!```HH/__BP``
M``!!#A"#`E(.L`$"<0H.$$$."$$+0````.`!``"4H/__W`````!"#A".`DH.
M&(T#0@X@C`1+#BB&!4$.,(,&1P[`(`*!"@XP00XH00X@0@X80@X00@X(1@L4
M````)`(``#"A__\P`````$0.$%8."``4````/`(``$BA__])`````$0.$`)`
M#@@H````5`(``("A__^Z`````$$.$(8"00X8@P-'#L!``JD*#AA!#A!!#@A!
M"Q````"``@``%*+__P4`````````7````)0"```0HO__`@(```!"#A"/`D(.
M&(X#0@X@C01"#BB,!40.,(8&2PXX@P='#O`A`F0*#CA!#C!!#BA"#B!"#AA"
M#A!"#@A$"P*6#O@A30Z`(FH.^"%!#O`A````$````/0"``#`H___*0``````
M```L````"`,``-RC___-`````%,.$(,"`DT*PPX(2`L"0`X(2,-0#A"#`DC#
M#@@````@````.`,``'RD___G`0```$$.$(,"2PY0`VP!"@X000X(1PL8````
M7`,``$BF__]T`````$0.(&\*#@A%"P``'````'@#``"LIO__)P````!$#A!8
M"@X(1`M&#@@````\````F`,``+RF___>`````$(.$(P"00X8A@-+#B"#!$0.
M,`),"@X@00X800X00@X(1@MN#CA)#D!T#CA!#C``M````-@#``!<I___(`L`
M``!"#A"/`DP.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M"#`@,.`@[8@P)A
M#N"#`F`.V(,"0@[0@P("?0H..$$.,$$.*$(.($(.&$(.$$(."$4+`WH!#MB#
M`DD.X(,"8`[8@P)!#M"#`EL.V(,"10[@@P)/#NB#`DT.\(,"2P[0@P(#JP0.
MV(,"1`[@@P)H#MB#`D$.T(,"`S\!"@[8@P)"#N"#`DP+`$@```"0!```Q+'_
M_^D#````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y0`\L""@XX
M00XP00XH0@X@0@X80@X00@X(10LP````W`0``&BU__]W`````$$.$(8"1`X8
M@P-$#B`"70H.&$$.$$$."$$+1`X81`X000X(*````!`%``!D?O__*0(```!!
M#A"&`D$.&(,#1`Y0`[D!"@X800X000X(00L4````/`4``(BU__\,````````
M``````!$````5`4``("U__]E`````$(.$(\"0@X8C@-%#B"-!$(.*(P%2`XP
MA@9(#CB#!TT.0'(..$$.,$$.*$(.($(.&$(.$$(."``0````G`4``*BU__\"
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"<`
M``````#`)@````````````````````````````````````````$`````````
M`0`````````!`````````,L!`````````0````````#6`0````````$`````
M````X`$````````!`````````"\"`````````0````````![`P````````P`
M`````````"`````````-`````````,1;````````&0````````!@NP``````
M`!L`````````"``````````:`````````&B[````````'``````````(````
M`````/7^_V\`````"`,````````%`````````(`-````````!@`````````(
M!`````````H`````````[`0````````+`````````!@`````````%0``````
M``````````````,`````````R+T````````"`````````(@%````````%```
M```````'`````````!<`````````4!4````````'`````````+@3````````
M"`````````"8`0````````D`````````&``````````>``````````@`````
M````^___;P`````!```(`````/[__V\`````.!,```````#___]O``````(`
M````````\/__;P````!L$@```````/G__V\`````!```````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(B[````````````````````
M`````````#8@````````1B````````!6(````````&8@````````=B``````
M``"&(````````)8@````````IB````````"V(````````,8@````````UB``
M``````#F(````````/8@````````!B$````````6(0```````"8A````````
M-B$```````!&(0```````%8A````````9B$```````!V(0```````(8A````
M````EB$```````"F(0```````+8A````````QB$```````#6(0```````.8A
M````````]B$````````&(@```````!8B````````)B(````````V(@``````
M`$8B````````5B(```````!F(@```````'8B````````AB(```````"6(@``
M`````*8B````````MB(```````#&(@```````-8B````````YB(```````#V
M(@````````8C````````%B,````````F(P```````#8C````````1B,`````
M``!6(P```````&8C````````=B,```````"&(P```````)8C````````IB,`
M``````"V(P```````,8C````````UB,`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P`````@8P```````$=#
M0SH@*$1E8FEA;B`X+C(N,"TW*2`X+C(N,`!'0T,Z("A$96)I86X@-RXS+C`M
M,CDI(#<N,RXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN
M;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG
M;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT
M`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1A=&$N
M<F5L+G)O`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````````
M````````````````````````````````````````````````````````````
M```````````````````+`````0````(`````````J`(```````"H`@``````
M`!P````````````````````!````````````````````$P````<````"````
M`````,0"````````Q`(````````@````````````````````!```````````
M`````````"$````'`````@````````#D`@```````.0"````````)```````
M``````````````0````````````````````T````]O__;P(`````````"`,`
M```````(`P```````/P`````````!0`````````(````````````````````
M/@````L````"``````````@$````````"`0```````!X"0````````8````!
M````"``````````8`````````$8````#`````@````````"`#0```````(`-
M````````[`0```````````````````$```````````````````!.````____
M;P(`````````;!(```````!L$@```````,H`````````!0`````````"````
M``````(`````````6P```/[__V\"`````````#@3````````.!,```````"`
M``````````8````"````"````````````````````&H````$`````@``````
M``"X$P```````+@3````````F`$````````%``````````@`````````&```
M``````!T````!````$(`````````4!4```````!0%0```````(@%````````
M!0```!<````(`````````!@`````````?@````$````&```````````@````
M`````"`````````7````````````````````!````````````````````'D`
M```!````!@`````````@(````````"`@````````P`,`````````````````
M`!``````````$`````````"$`````0````8`````````X",```````#@(P``
M``````@````````````````````(``````````@`````````C0````$````&
M`````````/`C````````\",```````#2-P``````````````````$```````
M`````````````),````!````!@````````#$6P```````,1;````````"0``
M``````````````````0```````````````````"9`````0````(`````````
M`&``````````8````````%@_```````````````````(````````````````
M````H0````$````"`````````%B?````````6)\```````#L````````````
M````````!````````````````````*\````!`````@````````!(H```````
M`$B@````````X`4```````````````````@```````````````````"Y````
M#@````,`````````8+L```````!@JP````````@````````````````````(
M``````````@`````````Q0````\````#`````````&B[````````:*L`````
M```(````````````````````"``````````(`````````-$````!`````P``
M``````!PNP```````'"K````````$P```````````````````!``````````
M``````````#>````!@````,`````````B+L```````"(JP```````$`"````
M````!@`````````(`````````!``````````B`````$````#`````````,B]
M````````R*T````````P`@``````````````````"``````````(````````
M`.<````!`````P``````````P`````````"P````````(```````````````
M``````@```````````````````#M````"`````,`````````(,`````````@
ML````````(@0```````````````````@````````````````````\@````$`
M```P````````````````````(+`````````Y`````````````````````0``
M```````!``````````$````#`````````````````````````%FP````````
@^P````````````````````$`````````````````````
